@@ -46,7 +46,30 @@ plotComparedLargeScaleCharacteristics <- function(data,
                                                   facet = NULL,
                                                   colorVars = NULL,
                                                   missings = 0) {
-  if (length(data$result_id) != 0) {
+
+  rlang::check_installed("ggplot2")
+  rlang::check_installed("ggpubr")
+  rlang::check_installed("scales")
+
+  if (!inherits(data, "summarised_result")) {
+    cli::cli_abort("result must be a summarised result")
+  }
+  if (nrow(data) == 0) {
+    cli::cli_warn("Empty result object")
+    return(emptyPlot())
+  }
+
+  data <- data |>
+    visOmopResults::filterSettings(.data$result_type == "summarised_large_scale_characteristics")
+
+
+  if (nrow(data) == 0) {
+    cli::cli_warn("No summarised characteristics results found")
+    return(emptyPlot())
+  }
+
+
+   if (length(data$result_id) != 0) {
     checkSettings(data)
 
     referenceGroupLevel <- checkReference(referenceGroupLevel, data, type = "group_level", argument = "referenceGroupLevel")
